==> apache-ignite-3.0.0-src.zip: apache-ignite-3.0.0-src/modules/runner/src/testFixtures/java/org/apache/ignite/internal/ReplicationGroupsUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal;

import static java.util.stream.Collectors.toList;

import java.util.List;
import org.apache.ignite.internal.app.IgniteImpl;
import org.apache.ignite.internal.raft.RaftNodeId;
import org.apache.ignite.internal.replicator.TablePartitionId;

/**
 * Utilities used to obtain replication groups from a running Ignite instance.
 */
public class ReplicationGroupsUtils {
    /**
     * Returns the IDs of all table partitions that exist on the given node.
     */
    public static List<TablePartitionId> tablePartitionIds(IgniteImpl node) {
        return node.raftManager().localNodes().stream()
                .map(RaftNodeId::groupId)
                .filter(TablePartitionId.class::isInstance)
                .map(TablePartitionId.class::cast)
                .collect(toList());
    }
}

==> apache-ignite-3.1.0-src.zip: apache-ignite-3.1.0-src/modules/runner/src/testFixtures/java/org/apache/ignite/internal/ReplicationGroupsUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal;

import static java.util.stream.Collectors.toList;

import java.util.List;
import org.apache.ignite.internal.app.IgniteImpl;
import org.apache.ignite.internal.raft.RaftNodeId;
import org.apache.ignite.internal.replicator.TablePartitionId;
import org.apache.ignite.internal.replicator.ZonePartitionId;

/**
 * Utilities used to obtain replication groups from a running Ignite instance.
 */
public class ReplicationGroupsUtils {
    /**
     * Returns the IDs of all table partitions that exist on the given node.
     */
    public static List<TablePartitionId> tablePartitionIds(IgniteImpl node, int tableId) {
        return node.raftManager().localNodes().stream()
                .map(RaftNodeId::groupId)
                .filter(TablePartitionId.class::isInstance)
                .map(TablePartitionId.class::cast)
                .filter(tablePartitionId -> tablePartitionId.tableId() == tableId)
                .collect(toList());
    }

    /**
     * Returns the IDs of all zone partitions that exist on the given node.
     */
    public static List<ZonePartitionId> zonePartitionIds(IgniteImpl node, int zoneId) {
        return node.raftManager().localNodes().stream()
                .map(RaftNodeId::groupId)
                .filter(ZonePartitionId.class::isInstance)
                .map(ZonePartitionId.class::cast)
                .filter(zonePartitionId -> zonePartitionId.zoneId() == zoneId)
                .collect(toList());
    }
}
